@@ -1,3 +1,3 @@
-from . import common, config, connection_manager, encryption, features, shell
+from . import common, connection_manager, encryption, features, shell
 from .main import LogicHubCLI
 from .connection_manager import LogicHubConnection
